Logo
Explore Help
Sign In
iHore/vLLM
Watch 8
Star 0
Fork 0
Code Issues Pull Requests Actions 1 Packages Projects Releases Wiki Activity
Files
dffbb714e4e8e4b95ccc888df98d47c7d2cef78d
vLLM/vllm/models/glm5next/nvidia
T
History
Jared WenClaude Fable 5.1mergify[bot] <37929162+mergify[bot]@users.noreply.github.com>
b443c1cc4e [Perf][GLM-5.3-Flash] Use FlashKDA for KDA chunked prefill (1.7-3.8x faster than the Triton chunk path) (#55737)
Signed-off-by: Jared Wen <jaredwen@inferact.ai>
Co-authored-by: Claude Fable 5.1 <noreply@anthropic.com>
Co-authored-by: mergify[bot] <37929162+mergify[bot]@users.noreply.github.com>
2026-09-14 08:36:19 +00:00
..
ops
[Perf][GLM-5.3-Flash] Decode hot-path cleanups: strided KDA recurrent inputs, NoPE MQA query without concat, no duplicate router GEMM (#55736)
2026-09-10 16:28:33 +08:00
__init__.py
[Bugfix][Docs] Package glm5next nvidia subtree and fix its docstrings (#55214)
2026-09-03 21:25:26 -07:00
attention.py
…
kda.py
[Perf][GLM-5.3-Flash] Use FlashKDA for KDA chunked prefill (1.7-3.8x faster than the Triton chunk path) (#55737)
2026-09-14 08:36:19 +00:00
model.py
[9/N][warmup][DSv4] Migrate MHC TileLang kernels (#50178)
2026-09-12 17:25:23 -07:00
mtp.py
[Feat] Add EPLB support for GLM-5.3-Flash (#55119)
2026-09-05 05:28:33 +00:00
multimodal.py
…
Powered by Gitea Version: 1.27.2 Page: 1028ms Template: 7ms
Auto
English
Bahasa Indonesia Deutsch English Español Français Gaeilge Italiano Latviešu Magyar nyelv Nederlands Polski Português de Portugal Português do Brasil Suomi Svenska Türkçe Čeština Ελληνικά Български Русский Українська فارسی മലയാളം 日本語 简体中文 繁體中文(台灣) 繁體中文(香港) 한국어
Licenses API